<TS language="eo" version="2.0">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Krei novan adreson</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nova</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Kopii elektitan adreson al la tondejo</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Kopii</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Forigi la elektitan adreson el la listo</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Forigi</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>Kopii &amp;Etikedon</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Redakti</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Etikedo</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adreso</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(neniu etikedo)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Dialogo pri pasfrazo</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Enigu pasfrazon</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Nova pasfrazo</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Ripetu la novan pasfrazon</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>?ifri la monujon</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>?i tiu operacio bezonas vian monujan pasfrazon, por mal?losi la monujon.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Mal?losi la monujon</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>?an?i la pasfrazon</translation>
    </message>
    <message>
        <source>Enter the old and new passphrase to the wallet.</source>
        <translation>Tajpu la malnovan kaj novan monujajn pasfrazojn.</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Konfirmo de ?ifrado de la monujo</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>?u vi certas, ke vi volas ?ifri la monujon?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>La monujo estas ?ifrita</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation>GRAVE: anta?aj sekur-kopioj de via monujo-dosiero estas forigindaj kiam vi havas nove kreitan ?ifritan monujo-dosieron. Pro sekureco, anta?aj kopioj de la ne?ifrita dosiero ne plu funkcios tuj kiam vi ekuzos la novan ?ifritan dosieron.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>?ifrado de la monujo fiaskis</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>?ifrado de monujo fiaskis pro interna eraro. Via monujo ne estas ?ifrita.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>La pasfrazoj entajpitaj ne samas.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>Mal?loso de la monujo fiaskis</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>La pasfrazo enigita por ?ifrado de monujo ne ?ustas.</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>Vi sukcese ?an?is la pasfrazon de la monujo.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>Atentu: la majuskla baskulo estas ?altita!</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Wallet</source>
        <translation>Monujo</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Superrigardo</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Vidigi ĝeneralan superrigardon de la monujo</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Sendi</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;Ricevi</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Esplori historion de transakcioj</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;Eliri</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Eliri la aplikaĵon</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Agordoj...</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;Montri / Kaŝi</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>Ĉifri &amp;Monujon...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>Ŝanĝi &amp;Pasfrazon...</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Ŝanĝi la pasfrazon por ĉifri la monujon</translation>
    </message>
    <message>
        <source>Sign &amp;message...</source>
        <translation>Subskribi &amp;mesaĝon...</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>&amp;Kontroli mesaĝon...</translation>
    </message>
    <message>
        <source>&amp;Debug window</source>
        <translation>Sen&amp;cimiga fenestro</translation>
    </message>
    <message>
        <source>Open debugging and diagnostic console</source>
        <translation>Malfermi konzolon de sencimigo kaj diagnozo</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Dosiero</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Agordoj</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Helpo</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to the Gridcoin network</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n second(s) ago</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s) ago</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Ĝisdata</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>Ĝisdatigante...</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Sendita transakcio</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Envenanta transakcio</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>Monujo estas &lt;b&gt;ĉifrita&lt;/b&gt; kaj aktuale &lt;b&gt;ŝlosita&lt;/b&gt;</translation>
    </message>
    </context>
<context>
    <name>ClientModel</name>
    <message>
        <source>Network Alert</source>
        <translation>Reta Averto</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>Kvanto:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Bajtoj:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Sumo:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Krompago:</translation>
    </message>
    <message>
        <source>Low Output:</source>
        <translation>Malalta Eligo:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Post krompago:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Restmono:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Sumo</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Dato</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>Konfirmoj</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Konfirmita</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adreso</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Kopii adreson</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Kopii etikedon</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopii sumon</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>Kopii transakcian ID-on</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Kopii kvanton</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Kopii krompagon</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>Kopii post krompago</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Kopii bajtojn</translation>
    </message>
    <message>
        <source>Copy low output</source>
        <translation>Kopii malaltan eligon</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Kopii restmonon</translation>
    </message>
    <message>
        <source>yes</source>
        <translation>jes</translation>
    </message>
    <message>
        <source>no</source>
        <translation>ne</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(neniu etikedo)</translation>
    </message>
    <message>
        <source>change from %1 (%2)</source>
        <translation>restmono de %1 (%2)</translation>
    </message>
    <message>
        <source>(change)</source>
        <translation>(restmono)</translation>
    </message>
</context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Redakti Adreson</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;Etikedo</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Adreso</translation>
    </message>
    <message>
        <source>New receiving address</source>
        <translation>Nova adreso por ricevi</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>Nova adreso por sendi</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation>Redakti adreson por ricevi</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation>Redakti adreson por sendi</translation>
    </message>
    <message>
        <source>The entered address "%1" is already in the address book.</source>
        <translation>La adreso enigita "%1" jam ekzistas en la adresaro.</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>Ne eblis mal?losi monujon.</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation>Fiaskis kreo de nova ?losilo.</translation>
    </message>
</context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of free space available</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Agordaĵoj</translation>
    </message>
    <message>
        <source>&amp;Main</source>
        <translation>Ĉ&amp;efa</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation>&amp;Reto</translation>
    </message>
    <message>
        <source>Map port using &amp;UPnP</source>
        <translation>Mapigi pordon per &amp;UPnP</translation>
    </message>
    <message>
        <source>&amp;Port:</source>
        <translation>&amp;Pordo:</translation>
    </message>
    <message>
        <source>Port of the proxy (e.g. 9050)</source>
        <translation>la pordo de la prokurilo (ekz. 9050)</translation>
    </message>
    <message>
        <source>Minimize instead of exit the application when the window is closed. When this option is enabled, the application will be closed only after selecting Quit in the menu.</source>
        <translation>Minimumigi la aplika?on anstata? eliri kaj ?esi kiam la fenestro estas fermita. Se tiu ?i estas agordita, la aplika?o ?esas nur kiam oni elektas "Eliri" el la menuo.</translation>
    </message>
    <message>
        <source>&amp;Display addresses in transaction list</source>
        <translation>&amp;Montri adresojn en la listo de transakcioj</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Fenestro</translation>
    </message>
    <message>
        <source>Show only a tray icon after minimizing the window.</source>
        <translation>Montri nur sistempletan piktogramon post minimumigo de la fenestro.</translation>
    </message>
    <message>
        <source>&amp;Minimize to the tray instead of the taskbar</source>
        <translation>&amp;Minimumigi al la sistempleto anstataŭ al la taskopleto</translation>
    </message>
    <message>
        <source>M&amp;inimize on close</source>
        <translation>M&amp;inimumigi je fermo</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation>&amp;Aspekto</translation>
    </message>
    <message>
        <source>User Interface &amp;language:</source>
        <translation>&amp;Lingvo de la fasado:</translation>
    </message>
    <message>
        <source>&amp;Unit to show amounts in:</source>
        <translation>&amp;Unuo por vidigi sumojn:</translation>
    </message>
    <message>
        <source>Choose the default subdivision unit to show in the interface and when sending coins.</source>
        <translation>Elekti la defaŭltan manieron por montri bitmonajn sumojn en la interfaco, kaj kiam vi sendos bitmonon.</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Bone</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Nuligi</translation>
    </message>
    <message>
        <source>default</source>
        <translation>defaŭlta</translation>
    </message>
    <message>
        <source>The supplied proxy address is invalid.</source>
        <translation>La prokurila adreso estas malvalida.</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>Formularo</translation>
    </message>
    <message>
        <source>Your current spendable balance</source>
        <translation>via aktuala elspezebla saldo</translation>
    </message>
    <message>
        <source>Immature:</source>
        <translation>Nematura:</translation>
    </message>
    <message>
        <source>Total:</source>
        <translation>Totalo:</translation>
    </message>
    <message>
        <source>Your current total balance</source>
        <translation>via aktuala totala saldo</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>N/A</source>
        <translation>neaplikebla</translation>
    </message>
    <message>
        <source>Client version</source>
        <translation>Versio de kliento</translation>
    </message>
    <message>
        <source>&amp;Information</source>
        <translation>&amp;Informoj</translation>
    </message>
    <message>
        <source>Startup time</source>
        <translation>Horo de lanĉo</translation>
    </message>
    <message>
        <source>Number of connections</source>
        <translation>Nombro de konektoj</translation>
    </message>
    <message>
        <source>Block chain</source>
        <translation>Blokĉeno</translation>
    </message>
    <message>
        <source>Current number of blocks</source>
        <translation>Aktuala nombro de blokoj</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>Horo de la lasta bloko</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Malfermi</translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation>&amp;Forigi ĉion</translation>
    </message>
    <message>
        <source>&amp;Console</source>
        <translation>&amp;Konzolo</translation>
    </message>
    <message>
        <source>&amp;Network Traffic</source>
        <translation>&amp;Reta Trafiko</translation>
    </message>
    <message>
        <source>Totals</source>
        <translation>Totaloj</translation>
    </message>
    <message>
        <source>In:</source>
        <translation>En:</translation>
    </message>
    <message>
        <source>Out:</source>
        <translation>El:</translation>
    </message>
    <message>
        <source>Debug log file</source>
        <translation>Sencimiga protokoldosiero</translation>
    </message>
    <message>
        <source>Clear console</source>
        <translation>Malplenigi konzolon</translation>
    </message>
    <message>
        <source>Estimated total blocks</source>
        <translation>Supozita totalo da blokoj</translation>
    </message>
    <message>
        <source>Client name</source>
        <translation>Nomo de kliento</translation>
    </message>
    <message>
        <source>Use up and down arrows to navigate history, and &lt;b&gt;Ctrl-L&lt;/b&gt; to clear screen.</source>
        <translation>Uzu la sagojn supran kaj malsupran por esplori la historion, kaj &lt;b&gt;stir-L&lt;/b&gt; por malplenigi la ekranon.</translation>
    </message>
    <message>
        <source>Type &lt;b&gt;help&lt;/b&gt; for an overview of available commands.</source>
        <translation>Tajpu &lt;b&gt;help&lt;/b&gt; por superrigardo de la disponeblaj komandoj.</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>Sendi Bitmonon</translation>
    </message>
    <message>
        <source>Inputs...</source>
        <translation>Enigoj...</translation>
    </message>
    <message>
        <source>Insufficient funds!</source>
        <translation>Nesufiĉa mono!</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>Kvanto:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Bajtoj:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Sumo:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Krompago:</translation>
    </message>
    <message>
        <source>Low Output:</source>
        <translation>Malalta Eligo:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Post krompago:</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>Sendi samtempe al pluraj ricevantoj</translation>
    </message>
    <message>
        <source>Add &amp;Recipient</source>
        <translation>Aldoni &amp;Ricevonton</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>&amp;Forigi Ĉion</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>Konfirmi la sendon</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation>Ŝendi</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Kopii kvanton</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopii sumon</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Kopii krompagon</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>Kopii post krompago</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Kopii bajtojn</translation>
    </message>
    <message>
        <source>Copy low output</source>
        <translation>Kopii malaltan eligon</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Kopii restmonon</translation>
    </message>
    <message>
        <source>Confirm send coins</source>
        <translation>Konfirmi sendon de bitmono</translation>
    </message>
    <message>
        <source>The recipient address is not valid, please recheck.</source>
        <translation>La adreso de la ricevonto ne validas. Bonvolu kontroli.</translation>
    </message>
    <message>
        <source>The amount to pay must be larger than 0.</source>
        <translation>La pagenda sumo devas esti pli ol 0.</translation>
    </message>
    <message>
        <source>The amount exceeds your balance.</source>
        <translation>La sumo estas pli granda ol via saldo.</translation>
    </message>
    <message>
        <source>The total exceeds your balance when the %1 transaction fee is included.</source>
        <translation>La sumo kun la %1 krompago estas pli granda ol via saldo.</translation>
    </message>
    <message>
        <source>Duplicate address found, can only send to each address once per send operation.</source>
        <translation>Iu adreso estas ripetita. Vi povas sendi al ?iu adreso po unufoje en iu send-operacio.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(neniu etikedo)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>&amp;Sumo:</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation>&amp;Ricevonto:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Mesaĝo:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Etikedo:</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Alglui adreson de tondejo</translation>
    </message>
    <message>
        <source>Enter a label for this address to add it to your address book</source>
        <translation>Tajpu etikedon por tiu ?i adreso kaj aldonu ?in al via adresaro</translation>
    </message>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Signatures - Sign / Verify a Message</source>
        <translation>Subskriboj - Subskribi / Kontroli mesaĝon</translation>
    </message>
    <message>
        <source>&amp;Sign Message</source>
        <translation>&amp;Subskribi Mesaĝon</translation>
    </message>
    <message>
        <source>You can sign messages with your addresses to prove you own them. Be careful not to sign anything vague, as phishing attacks may try to trick you into signing your identity over to them. Only sign fully-detailed statements you agree to.</source>
        <translation>Vi povas subskribi mesa?on per viaj adresoj, por pravigi ke vi estas la posedanto de tiuj adresoj. Atentu, ke vi ne subskriu ion neprecizan, ?ar trompisto povus ruzi kontra? vi kaj ?teli vian identecon. Subskribu nur plene detaligitaj deklaroj pri kiuj vi konsentas.</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Alglui adreson de tondejo</translation>
    </message>
    <message>
        <source>Enter the message you want to sign here</source>
        <translation>Tajpu la mesaĝon, kiun vi volas sendi, cîi tie</translation>
    </message>
    <message>
        <source>Copy the current signature to the system clipboard</source>
        <translation>Kopii la aktualan subskribon al la tondejo</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>Subskribi &amp;Mesaĝon</translation>
    </message>
    <message>
        <source>Reset all sign message fields</source>
        <translation>Reagordigi ĉiujn prisubskribajn kampojn</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>&amp;Forigi Ĉion</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>&amp;Kontroli Mesaĝon</translation>
    </message>
    <message>
        <source>Enter the signing address, message (ensure you copy line breaks, spaces, tabs, etc. exactly) and signature below to verify the message. Be careful not to read more into the signature than what is in the signed message itself, to avoid being tricked by a man-in-the-middle attack.</source>
        <translation>Enmeti la subskriban adreson, la mesa?on (kune kun ?iu linisalto, spaceto, taboj, ktp. precize) kaj la subskribon ?i sube por kontroli la mesa?on. Atentu, ke vi ne komprenu per la subskribo pli ol la enhavo de la mesa?o mem, por eviti homo-en-la-mezo-atakon.</translation>
    </message>
    <message>
        <source>Reset all verify message fields</source>
        <translation>Reagordigi ĉiujn prikontrolajn kampojn</translation>
    </message>
    <message>
        <source>Click "Sign Message" to generate signature</source>
        <translation>Klaku "Subskribi Mesa?on" por krei subskribon</translation>
    </message>
    <message>
        <source>The entered address is invalid.</source>
        <translation>La adreso, kiun vi enmetis, estas nevalida.</translation>
    </message>
    <message>
        <source>Please check the address and try again.</source>
        <translation>Bonvolu kontroli la adreson kaj reprovi.</translation>
    </message>
    <message>
        <source>The entered address does not refer to a key.</source>
        <translation>La adreso, kiun vi enmetis, referencas neniun ?losilon.</translation>
    </message>
    <message>
        <source>Wallet unlock was cancelled.</source>
        <translation>Mal?loso de monujo estas nuligita.</translation>
    </message>
    <message>
        <source>Private key for the entered address is not available.</source>
        <translation>La privata ?losilo por la enigita adreso ne disponeblas.</translation>
    </message>
    <message>
        <source>Message signing failed.</source>
        <translation>Subskribo de mesa?o fiaskis.</translation>
    </message>
    <message>
        <source>Message signed.</source>
        <translation>Mesa?o estas subskribita.</translation>
    </message>
    <message>
        <source>The signature could not be decoded.</source>
        <translation>Ne eblis mal?ifri la subskribon.</translation>
    </message>
    <message>
        <source>Please check the signature and try again.</source>
        <translation>Bonvolu kontroli la subskribon kaj reprovu.</translation>
    </message>
    <message>
        <source>The signature did not match the message digest.</source>
        <translation>La subskribo ne kongruis kun la mesa?-kompila?o.</translation>
    </message>
    <message>
        <source>Message verification failed.</source>
        <translation>Kontrolo de mesa?o malsukcesis.</translation>
    </message>
    <message>
        <source>Message verified.</source>
        <translation>Mesa?o sukcese kontrolita.</translation>
    </message>
</context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Malferma ?is %1</translation>
    </message>
    <message>
        <source>%1/offline</source>
        <translation>%1/senkonekte</translation>
    </message>
    <message>
        <source>%1/unconfirmed</source>
        <translation>%1/nekonfirmite</translation>
    </message>
    <message>
        <source>%1 confirmations</source>
        <translation>%1 konfirmoj</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Stato</translation>
    </message>
    <message>
        <source>, has not been successfully broadcast yet</source>
        <translation>, ankora? ne elsendita sukcese</translation>
    </message>
    <message numerus="yes">
        <source>, broadcast through %n node(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Dato</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Fonto</translation>
    </message>
    <message>
        <source>From</source>
        <translation>De</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>nekonata</translation>
    </message>
    <message>
        <source>To</source>
        <translation>Al</translation>
    </message>
    <message>
        <source>own address</source>
        <translation>propra adreso</translation>
    </message>
    <message>
        <source>label</source>
        <translation>etikedo</translation>
    </message>
    <message>
        <source>Credit</source>
        <translation>Kredito</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message>
        <source>not accepted</source>
        <translation>ne akceptita</translation>
    </message>
    <message>
        <source>Debit</source>
        <translation>Debeto</translation>
    </message>
    <message>
        <source>Transaction fee</source>
        <translation>Krompago</translation>
    </message>
    <message>
        <source>Net amount</source>
        <translation>Neta sumo</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Mesa?o</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Komento</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Sumo</translation>
    </message>
    <message>
        <source>true</source>
        <translation>vera</translation>
    </message>
    <message>
        <source>false</source>
        <translation>malvera</translation>
    </message>
</context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>Transaction details</source>
        <translation>Transakciaj detaloj</translation>
    </message>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation>Tiu ĉi panelo montras detalan priskribon de la transakcio</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Dato</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adreso</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Sumo</translation>
    </message>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Malferma ?is %1</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>Senkonekte</translation>
    </message>
    <message>
        <source>Unconfirmed</source>
        <translation>Nekonfirmita</translation>
    </message>
    <message>
        <source>Confirmed (%1 confirmations)</source>
        <translation>Konfirmita (%1 konfirmoj)</translation>
    </message>
    <message>
        <source>Generated but not accepted</source>
        <translation>Kreita sed ne akceptita</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Ricevita kun</translation>
    </message>
    <message>
        <source>Received from</source>
        <translation>Ricevita de</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Sendita al</translation>
    </message>
    <message>
        <source>Payment to yourself</source>
        <translation>Pago al vi mem</translation>
    </message>
    <message>
        <source>(n/a)</source>
        <translation>neaplikebla</translation>
    </message>
    <message>
        <source>Transaction status. Hover over this field to show number of confirmations.</source>
        <translation>Transakcia stato. ?vebi super tiu ?i kampo por montri la nombron de konfirmoj.</translation>
    </message>
    <message>
        <source>Date and time that the transaction was received.</source>
        <translation>Dato kaj horo kiam la transakcio alvenis.</translation>
    </message>
    <message>
        <source>Type of transaction.</source>
        <translation>Tipo de transakcio.</translation>
    </message>
    <message>
        <source>Destination address of transaction.</source>
        <translation>Celadreso de la transakcio.</translation>
    </message>
    <message>
        <source>Amount removed from or added to balance.</source>
        <translation>Sumo elprenita de a? aldonita al la saldo.</translation>
    </message>
</context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Today</source>
        <translation>Hodia?</translation>
    </message>
    <message>
        <source>This week</source>
        <translation>?i-semajne</translation>
    </message>
    <message>
        <source>This month</source>
        <translation>?i-monate</translation>
    </message>
    <message>
        <source>Last month</source>
        <translation>Pasintmonate</translation>
    </message>
    <message>
        <source>This year</source>
        <translation>?i-jare</translation>
    </message>
    <message>
        <source>Range...</source>
        <translation>Intervalo...</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Ricevita kun</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Sendita al</translation>
    </message>
    <message>
        <source>To yourself</source>
        <translation>Al vi mem</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>Minita</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Aliaj</translation>
    </message>
    <message>
        <source>Min amount</source>
        <translation>Minimuma sumo</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Kopii adreson</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Kopii etikedon</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopii sumon</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>Kopii transakcian ID-on</translation>
    </message>
    <message>
        <source>Edit label</source>
        <translation>Redakti etikedon</translation>
    </message>
    <message>
        <source>Show transaction details</source>
        <translation>Montri detalojn de transakcio</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Konfirmita</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Dato</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Etikedo</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adreso</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Sumo</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation>Intervalo:</translation>
    </message>
    <message>
        <source>to</source>
        <translation>al</translation>
    </message>
</context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>An error occurred while setting up the RPC port %u for listening on IPv6, falling back to IPv4: %s</source>
        <translation>Eraro okazis dum estigo de RPC-pordo %u por a?skulti per IPv6; retrodefa?ltas al IPv4: %s</translation>
    </message>
    <message>
        <source>An error occurred while setting up the RPC port %u for listening on IPv4: %s</source>
        <translation>Eraro okazis dum estigo de RPC-pordo %u por a?skulti per IPv4: %s</translation>
    </message>
    <message>
        <source>Usage:</source>
        <translation>Uzado:</translation>
    </message>
    <message>
        <source>List commands</source>
        <translation>Listigi komandojn</translation>
    </message>
    <message>
        <source>Get help for a command</source>
        <translation>Vidigi helpon pri iu komando</translation>
    </message>
    <message>
        <source>Warning: -paytxfee is set very high! This is the transaction fee you will pay if you send a transaction.</source>
        <translation>Averto: -paytxfee estas agordita per tre alta valoro! Tio estas la krompago, kion vi pagos se vi sendas la transakcion.</translation>
    </message>
    <message>
        <source>Warning: wallet.dat corrupt, data salvaged! Original wallet.dat saved as wallet.{timestamp}.bak in %s; if your balance or transactions are incorrect you should restore from a backup.</source>
        <translation>Averto: via wallet.dat estas difektita, sed la datumoj sukcese savi?is! La originala wallet.dat estas nun konservita kiel wallet.{timestamp}.bak en %s; se via saldo a? transakcioj estas mal?ustaj vi devus resta?ri per alia sekurkopio.</translation>
    </message>
    <message>
        <source>Warning: error reading wallet.dat! All keys read correctly, but transaction data or address book entries might be missing or incorrect.</source>
        <translation>Averto: okazis eraro dum lego de wallet.dat! ?iuj ?losiloj sukcese legi?is, sed la transakciaj datumoj a? la adresaro eble mankas a? mal?ustas.</translation>
    </message>
    <message>
        <source>Failed to listen on any port. Use -listen=0 if you want this.</source>
        <translation>Ne sukcesis aŭskulti ajnan pordon. Uzu -listen=0 se tion vi volas.</translation>
    </message>
    <message>
        <source>To use the %s option</source>
        <translation>Por uzi la agordon %s</translation>
    </message>
    <message>
        <source>You must set rpcpassword=&lt;password&gt; in the configuration file:
%s
If the file does not exist, create it with owner-readable-only file permissions.</source>
        <translation>Vi devas agordi rpcpassword=&lt;password&gt; en la konfigura dosiero:
%s
Se la dosiero ne ekzistas, kreu ?in kun permeso "nur posedanto rajtas legi".</translation>
    </message>
    <message>
        <source>Invalid amount for -paytxfee=&lt;amount&gt;: '%s'</source>
        <translation>Nevalida sumo por -paytxfee=&lt;amount&gt;: '%s'</translation>
    </message>
    <message>
        <source>wallet.dat corrupt, salvage failed</source>
        <translation>wallet.dat estas difektita, riparo malsukcesis</translation>
    </message>
    <message>
        <source>Invalid -proxy address: '%s'</source>
        <translation>Nevalid adreso -proxy: '%s'</translation>
    </message>
    <message>
        <source>Cannot resolve -bind address: '%s'</source>
        <translation>Ne eblas trovi la adreson -bind: '%s'</translation>
    </message>
    <message>
        <source>Cannot resolve -externalip address: '%s'</source>
        <translation>Ne eblas trovi la adreson -externalip: '%s'</translation>
    </message>
    <message>
        <source>Error loading wallet.dat: Wallet corrupted</source>
        <translation>Eraro dum ?argado de wallet.dat: monujo difektita</translation>
    </message>
    <message>
        <source>Error loading wallet.dat</source>
        <translation>Eraro dum ?argado de wallet.dat</translation>
    </message>
    <message>
        <source>Loading addresses...</source>
        <translation>Ŝarĝante adresojn...</translation>
    </message>
    <message>
        <source>Unable to bind to %s on this computer (bind returned error %d, %s)</source>
        <translation>Ne eblis bindi al %s en tiu ?i komputilo (bind resendis eraron %d, %s)</translation>
    </message>
    <message>
        <source>Invalid amount</source>
        <translation>Nevalida sumo</translation>
    </message>
    <message>
        <source>Unknown network specified in -onlynet: '%s'</source>
        <translation>Nekonata reto specifita en -onlynet: '%s'</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>Nesufiĉa mono</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>Ŝarĝante blok-indekson...</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>Ŝargado de monujo...</translation>
    </message>
    <message>
        <source>Cannot write default address</source>
        <translation>Ne eblas skribi defaŭltan adreson</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>Reskanado...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>Ŝargado finiĝis</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Eraro</translation>
    </message>
</context>
</TS>